@@ -77,31 +77,6 @@ dialog_response_handler (GtkDialog *dlg, gint res_id,  GeditDialogGotoLine *dial
 	}
 }
 
-static void
-entry_insert_text (GtkEditable *editable, const char *text, gint length, gint *position)
-{
-	gunichar c;
-	const gchar *p;
- 	const gchar *end;
-
-	p = text;
-	end = text + length;
-
-	while (p != end) {
-		const gchar *next;
-		next = g_utf8_next_char (p);
-
-		c = g_utf8_get_char (p);
-
-		if (!g_unichar_isdigit (c)) {
-			g_signal_stop_emission_by_name (editable, "insert_text");
-			break;
-		}
-
-		p = next;
-	}
-}
-
 static GeditDialogGotoLine *
 dialog_goto_line_get_dialog (void)
 {
@@ -136,7 +111,7 @@ dialog_goto_line_get_dialog (void)
 
 	dialog = g_new0 (GeditDialogGotoLine, 1);
 
-	dialog->dialog = gtk_dialog_new_with_buttons (_("Go to Line"),
+	dialog->dialog = gtk_dialog_new_with_buttons (_("Goto line..."),
 						      window,
 						      GTK_DIALOG_DESTROY_WITH_PARENT,
 						      GTK_STOCK_CLOSE,
@@ -146,7 +121,7 @@ dialog_goto_line_get_dialog (void)
 	g_return_val_if_fail (dialog->dialog != NULL, NULL);
 
 	/* Add Goto Line button */
-	button = gedit_button_new_with_stock_image (_("_Go to Line"), GTK_STOCK_JUMP_TO);
+	button = gedit_button_new_with_stock_image (_("_Goto line"), GTK_STOCK_JUMP_TO);
 	g_return_val_if_fail (button != NULL, NULL);
 
 	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
@@ -162,8 +137,7 @@ dialog_goto_line_get_dialog (void)
 
 	if (!dialog->entry) {
 		g_warning (
-			_("Could not find the required widgets inside %s."),
-			"goto-line.glade2");
+			_("Could not find the required widgets inside goto-line.glade2.\n"));
 		g_object_unref (gui);
 		return NULL;
 	}
@@ -174,14 +148,11 @@ dialog_goto_line_get_dialog (void)
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog->dialog),
 					 GTK_RESPONSE_OK);
 
-	g_signal_connect (G_OBJECT (dialog->entry), "insert_text",
-			  G_CALLBACK (entry_insert_text), dialog);
+	gtk_signal_connect(GTK_OBJECT (dialog->dialog), "destroy",
+			   GTK_SIGNAL_FUNC (dialog_destroyed), &dialog);
 
-	g_signal_connect (G_OBJECT (dialog->dialog), "destroy",
-			  G_CALLBACK (dialog_destroyed), &dialog);
-
-	g_signal_connect (G_OBJECT (dialog->dialog), "response",
-			  G_CALLBACK (dialog_response_handler), dialog);
+	gtk_signal_connect(GTK_OBJECT (dialog->dialog), "response",
+			   GTK_SIGNAL_FUNC (dialog_response_handler), dialog);
 
 	g_object_unref (gui);
 
