@@ -4,7 +4,7 @@
  * This file is part of gedit
  *
  * Copyright (C) 1998, 1999 Alex Roberts, Evan Lawrence
- * Copyright (C) 2000, 2001 Chema Celorio, Paolo Maggi 
+ * Copyright (C) 2000, 2002 Chema Celorio, Paolo Maggi 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,11 +19,11 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, 
- * Boston, MA 02111-1307, USA. * *
+ * Boston, MA 02111-1307, USA.
  */
  
 /*
- * Modified by the gedit Team, 1998-2001. See the AUTHORS file for a 
+ * Modified by the gedit Team, 1998-2002. See the AUTHORS file for a 
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  */
@@ -81,8 +81,8 @@ struct _GeditDocumentClass
 
 };
 
-#define GEDIT_DOCUMENT_IO_ERROR gedit_document_io_error_quark()
-GQuark 		gedit_document_io_error_quark();
+#define GEDIT_DOCUMENT_IO_ERROR gedit_document_io_error_quark ()
+GQuark 		gedit_document_io_error_quark (void);
 
 GType        	gedit_document_get_type      	(void) G_GNUC_CONST;
 
@@ -120,13 +120,20 @@ void		gedit_document_insert_text	(GeditDocument *doc,
 						 gint	        pos,
                                                  const gchar   *text,
                                                  gint           len);
+
+void		gedit_document_insert_text_at_cursor (GeditDocument *doc, 
+                                                 const gchar   *text,
+                                                 gint           len);
+
 void 		gedit_document_delete_text 	(GeditDocument *doc, 
 		                                 gint start, gint end);
 
 gchar*		gedit_document_get_chars 	(GeditDocument *doc, 
 					         gint start, gint end);
 
-gchar*		gedit_document_get_selected_text (GeditDocument *doc);
+gchar*		gedit_document_get_selected_text (GeditDocument *doc,
+						  gint* start, gint* end);
+
 gboolean	gedit_document_has_selected_text (GeditDocument *doc);
 
 /* Multi-level Undo/Redo operations */
@@ -157,6 +164,7 @@ void		gedit_document_replace_selected_text (GeditDocument *doc,
 gboolean	gedit_document_replace_all (GeditDocument *doc,
 				            const gchar *find, const gchar *replace, 
 					    gboolean case_sensitive);
+guint		gedit_document_get_line_at_offset (const GeditDocument *doc, guint offset);
 
 #endif /* __GEDIT_DOCUMENT_H__ */
 
