@@ -42,12 +42,10 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "gedit-file-selector-util.h"
 
+#include <config.h>
+
 #include <bonobo/bonobo-file-selector-util.h>
 
 #include <string.h>
@@ -66,13 +64,12 @@
 
 #include <bonobo/bonobo-i18n.h>
 
-#include <libgnomevfs/gnome-vfs.h>
-#include <eel/eel-vfs-extensions.h>
-#include <eel/eel-string.h>
+#include <libgnomevfs/gnome-vfs-uri.h>
+#include <libgnomevfs/gnome-vfs-ops.h>
 
+#include "gnome-vfs-helpers.h"
 #include "gedit-utils.h"
 
-static GQuark user_data_id = 0;
 
 static gint
 delete_file_selector (GtkWidget *d, GdkEventAny *e, gpointer data)
@@ -87,26 +84,9 @@ replace_existing_file (GtkWindow *parent, const gchar* file_name)
 {
 	GtkWidget *msgbox;
 	gint ret;
-	gchar *full_formatted_uri;
-       	gchar *uri_for_display	;
-	gchar *uri;
-
-	uri = eel_make_uri_from_shell_arg (file_name);
-	g_return_val_if_fail (uri != NULL, FALSE);
-
-	full_formatted_uri = eel_format_uri_for_display (uri);
-	g_return_val_if_fail (full_formatted_uri != NULL, FALSE);
-	g_free (uri);
+	gchar* uri;
 	
-	/* Truncate the URI so it doesn't get insanely wide. Note that even
-	 * though the dialog uses wrapped text, if the URI doesn't contain
-	 * white space then the text-wrapping code is too stupid to wrap it.
-	 */
-        uri_for_display = eel_str_middle_truncate (full_formatted_uri, 50);
-	g_return_val_if_fail (uri_for_display != NULL, FALSE);
-
-	g_free (full_formatted_uri);
-
+	uri = gnome_vfs_x_format_uri_for_display (file_name);
 	msgbox = gtk_message_dialog_new (parent,
 			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_MESSAGE_QUESTION,
@@ -114,8 +94,8 @@ replace_existing_file (GtkWindow *parent, const gchar* file_name)
 			_("A file named ''%s'' already exists.\n"
 			  "Do you want to replace it with the "
 			  "one you are saving?"), 
-			uri_for_display);
-	g_free (uri_for_display);
+			uri);
+	g_free (uri);
 
 	/* Add Don't Replace button */
 	gedit_dialog_add_button (GTK_DIALOG (msgbox), 
@@ -174,9 +154,8 @@ listener_cb (BonoboListener *listener,
 			
 	gnome_vfs_uri_unref (uri);
 
-	g_object_set_qdata (G_OBJECT (dialog), 
-			   user_data_id,
-			   g_strdup (seq->_buffer[0]));
+	gtk_object_set_user_data (GTK_OBJECT (dialog),
+				  g_strdup (seq->_buffer[0]));
 
  cancel_clicked:
 	gtk_widget_hide (dialog);
@@ -188,8 +167,7 @@ listener_cb (BonoboListener *listener,
 static BonoboWidget *
 create_control (gboolean enable_vfs)
 {
-	CORBA_Environment ev;
-	BonoboWidget *bw;
+	GtkWidget *control;
 	char *moniker;
 
 	moniker = g_strdup_printf (
@@ -203,16 +181,10 @@ create_control (gboolean enable_vfs)
 		FALSE, 
 		TRUE);
 
-	bw = g_object_new (BONOBO_TYPE_WIDGET, NULL);
-	CORBA_exception_init (&ev);
-
-	bw = bonobo_widget_construct_control (
-		bw, moniker, CORBA_OBJECT_NIL, &ev);
-
-	CORBA_exception_free (&ev);
+	control = bonobo_widget_new_control (moniker, CORBA_OBJECT_NIL);
 	g_free (moniker);
 
-	return bw;
+	return control ? BONOBO_WIDGET (control) : NULL;
 }
 
 static GtkWindow *
@@ -231,7 +203,7 @@ create_bonobo_selector (gboolean    enable_vfs,
 
 	dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_container_add (GTK_CONTAINER (dialog), GTK_WIDGET (control));
-	gtk_widget_set_size_request (dialog, 560, 450);
+	gtk_widget_set_usize (dialog, 560, 450);
 
 	bonobo_event_source_client_add_listener (
 		bonobo_widget_get_objref (control), 
@@ -304,9 +276,8 @@ ok_clicked_cb (GtkWidget *widget, gpointer data)
 
 		gtk_widget_hide (GTK_WIDGET (fsel));
 
-		g_object_set_qdata (G_OBJECT (fsel),
-			    	   user_data_id,
-				   g_strdup (file_name));
+		gtk_object_set_user_data (GTK_OBJECT (fsel),
+					  g_strdup (file_name));
 		gtk_main_quit ();
 	} 
 }
@@ -316,10 +287,6 @@ cancel_clicked_cb (GtkWidget *widget, gpointer data)
 {
 	gtk_widget_hide (GTK_WIDGET (data));
 	gtk_main_quit ();
-
-	g_object_set_qdata (G_OBJECT (data),
- 		    	    user_data_id,
-			    NULL);
 }
 
 
@@ -333,13 +300,13 @@ create_gtk_selector (const char *default_path,
 
 	filesel = gtk_file_selection_new (NULL);
 
-	g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (filesel)->ok_button),
-			  "clicked", G_CALLBACK (ok_clicked_cb),
-			  filesel);
+	gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->ok_button),
+			    "clicked", GTK_SIGNAL_FUNC (ok_clicked_cb),
+			    filesel);
 
-	g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (filesel)->cancel_button),
-			  "clicked", G_CALLBACK (cancel_clicked_cb),
-			  filesel);
+	gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->cancel_button),
+			    "clicked", GTK_SIGNAL_FUNC (cancel_clicked_cb),
+			    filesel);
 
 	if (default_path)
 		path = g_strconcat (default_path, 
@@ -377,20 +344,13 @@ run_file_selector (GtkWindow  *parent,
 {
 	GtkWindow *dialog = NULL;
 	gpointer   retval;
-	gpointer   data;
-	gboolean   using_bonobo_filesel = FALSE;
 
-	if (!user_data_id)
-		user_data_id = g_quark_from_static_string ("GeditUserData");
 
 	if (!g_getenv ("GNOME_FILESEL_DISABLE_BONOBO"))
 		dialog = create_bonobo_selector (enable_vfs, mime_types, 
 						 default_path, default_filename);
-	
 	if (!dialog)
 		dialog = create_gtk_selector (default_path, default_filename);
-	else
-		using_bonobo_filesel = TRUE;
 
 	gtk_window_set_title (dialog, title);
 	gtk_window_set_modal (dialog, TRUE);
@@ -398,23 +358,15 @@ run_file_selector (GtkWindow  *parent,
 	if (parent)
 		gtk_window_set_transient_for (dialog, parent);
 	
-	g_signal_connect (G_OBJECT (dialog), "delete_event",
-			  G_CALLBACK (delete_file_selector),
-			  dialog);
+	gtk_signal_connect (GTK_OBJECT (dialog), "delete_event",
+			    GTK_SIGNAL_FUNC (delete_file_selector),
+			    dialog);
 
 	gtk_widget_show_all (GTK_WIDGET (dialog));
 
 	gtk_main ();
 
-	data = g_object_get_qdata (G_OBJECT (dialog), user_data_id);
-
-	if ((data != NULL) && enable_vfs && !using_bonobo_filesel)
-	{
-		retval = gnome_vfs_get_uri_from_local_path (data);
- 		g_free (data);
-	}
-	else
-		retval = data;
+	retval = gtk_object_get_user_data (GTK_OBJECT (dialog));
 
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 
